### Name: comp_train_pred
### Title: User-level functions for compressing parameters, training the
###   models with MCMC, and making predictions for test cases
### Aliases: begin.BPHO comp_train_pred cv_comp_train_pred
### Keywords: classif

### ** Examples

##  loading package
##  library("BPHO",lib.loc="~/rlib")

#####################################################################
########The following are demonstrations of using the whole package
#####################################################################

## generate data from a hidden Markov model
data_hmm <- gen_hmm(n=200,p=10,no_h=8,no_o=2,
                    prob_h_stay=0.8,prob_o_stay=0.8)

## compressing parameters, training model, making prediction
comp_train_pred(
        ################## specify data information  ################
        test_x=data_hmm$X[1:100,],train_x=data_hmm$X[-(1:100),],
        train_y=data_hmm$y[-(1:100)],no_cls=2,nos_fth=rep(2,10),
        ################## specify for compression ##################
        is_sequence=1,order=4,ptn_file=".ptn_file.log",
        new_compression=1,do_comp=1,
        ###################### specify for priors  ##################
        alpha=1,log_sigma_widths=c(),log_sigma_modes=c(),
        ################# specify for mc sampling ###################
        mc_file=".mc_file.log",start_over=TRUE,iters_mc=100,
        iters_bt=1,iters_sgm=2,w_bt=5,w_sgm=1,
        m_bt=20,m_sgm=20,ini_log_sigmas=c(),
        ################## specify for prediction ###################
        pred_file=".pred_file.csv",iter_b = 10,forward = 1,
        iters_pred = 90)

## display summary information about compression
display_ptn(ptn_file=".ptn_file.log")

## display the pattern information for group 1 and group 2
display_ptn(ptn_file=".ptn_file.log",gid=c(1,2))

## display the general information of Markov chain sampling
display_mc(mc_file=".mc_file.log")

## read Markov chain values of log-likelihood from  ".mc_file.log"
read_mc(group="lprobs",ix=0,mc_file=".mc_file.log",
        iter_b=0,forward=1,n=100)

## particularly read `betas' by specifying the group and class id
read_betas(mc_file=".mc_file.log",ix_g=5,ix_cls=2,
           iter_b=0,forward=1,n=100)

## display the information on the pattern related to a `beta'
display_a_beta(mc_file=".mc_file.log",
               ptn_file=".ptn_file.log",id_beta=5)

## calculate the medians of samples of each 'beta'
calc_medians_betas(mc_file=".mc_file.log",iter_b=10,forward=1,n=90)

## evaluate prediction with true values of the response
evaluate_prediction(
       test_y=data_hmm$y[1:100],
       pred_result=read.csv(".pred_file.csv"),
       file_eval_details="eval_details")

#perform cross-validation with training data only
cv_comp_train_pred(
        ################## specify data information  ################
        no_fold=2,train_x=data_hmm$X[-(1:100),],
        train_y=data_hmm$y[-(1:100)],no_cls=2,nos_fth=rep(2,10),
        ################## specify for compression ##################
        is_sequence=1,order=4,ptn_file=".ptn_file.log",
        new_compression=1,do_comp=1,
        ###################### specify for priors  ##################
        alpha=1,log_sigma_widths=c(),log_sigma_modes=c(),
        ################# specify for mc sampling ###################
        mc_file=".mc_file.log",iters_mc=100,
        iters_bt=1,iters_sgm=2,w_bt=5,w_sgm=1,
        m_bt=20,m_sgm=20,ini_log_sigmas=c(),
        ################## specify for prediction ###################
        pred_file=".pred_file.csv",iter_b = 10,forward = 1,
        iters_pred = 90)

#####################################################################
#####################################################################

## generating a classification data
data_class <- gen_bin_ho(n=400,p=3,order=3,alpha=1,
                 sigmas=c(0.3,0.2,0.1),nos_features=c(4,4,4),beta0=0)

## compressing parameters, training model, making prediction
comp_train_pred(
        ################## specify data information  ################
        test_x=data_class$X[1:100,],train_x=data_class$X[-(1:100),],
        train_y=data_class$y[-(1:100)],no_cls=2,nos_fth=rep(4,3),
        ################## specify for compression ##################
        is_sequence=0,order=3,ptn_file=".ptn_file.log",
        new_compression=1,do_comp=1,
        ###################### specify for priors  ##################
        alpha=1,log_sigma_widths=c(),log_sigma_modes=c(),
        ################# specify for mc sampling ###################
        mc_file=".mc_file.log",start_over=TRUE,iters_mc=500,
        iters_bt=1,iters_sgm=5,w_bt=5,w_sgm=0.5,
        m_bt=20,m_sgm=20,ini_log_sigmas=c(),
        ################## specify for prediction ###################
        pred_file=".pred_file.csv",iter_b = 100,forward = 1,
        iters_pred = 400)

## display summary information about compression
display_ptn(ptn_file=".ptn_file.log")

## display the pattern information for group 1 and group 2
display_ptn(ptn_file=".ptn_file.log",gid=c(1,2))

## display the general information of Markov chain sampling
display_mc(mc_file=".mc_file.log")

## read Markov chain values of log-likelihood from ".mc_file.log"
read_mc(group="lprobs",ix=0,mc_file=".mc_file.log",
        iter_b=0,forward=1,n=500)

## particularly read `betas' by specifying the group and class id
read_betas(mc_file=".mc_file.log",ix_g=5,ix_cls=2,
           iter_b=0,forward=1,n=500)

## display the information on the pattern related to a `beta'
display_a_beta(mc_file=".mc_file.log",ptn_file=".ptn_file.log",
               id_beta=5)

## calculate the medians of samples of each 'beta'
calc_medians_betas(mc_file=".mc_file.log",iter_b=100,forward=1,n=400)

## evaluate prediction with true values of the response
evaluate_prediction(
       test_y=data_class$y[1:100],
       pred_result=read.csv(".pred_file.csv"),
       file_eval_details="eval_details")



